=============
CLI Reference
=============

.. autoprogram-cliff:: cloudkittyclient
   :application: cloudkitty
   :ignored: --format, --column, --max-width, --fit-width, --print-empty, --format-config-file, --noindent, --quote, --sort-column
